@@ -1,7 +1,7 @@
 package Data::Sah::Coerce;
 
-our $DATE = '2016-06-12'; # DATE
-our $VERSION = '0.016'; # VERSION
+our $DATE = '2016-06-13'; # DATE
+our $VERSION = '0.017'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,12 +45,13 @@ sub gen_coercer {
 
     my $code;
     if (@$rules) {
-        # load all the required perl modules
+        my $code_require = '';
+        my %mem;
         for my $rule (@$rules) {
             next unless $rule->{modules};
             for my $mod (keys %{$rule->{modules}}) {
-                my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
-                require $mod_pm;
+                next if $mem{$mod}++;
+                $code_require .= "require $mod;\n";
             }
         }
 
@@ -74,6 +75,7 @@ sub gen_coercer {
 
         $code = join(
             "",
+            $code_require,
             "sub {\n",
             "    my \$data = shift;\n",
             ($rt_sv ?
@@ -117,7 +119,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.016 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-06-12.
+This document describes version 0.017 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-06-13.
 
 =head1 SYNOPSIS
 
